@@ -127,7 +127,7 @@ class CustomCommandsMenu(plugin.MenuItem):
       if command[-1] != '\n':
         command = command + '\n'
       for terminal in data['terminals']:
-        terminal.vte.feed_child(command,  len(command))
+        terminal.vte.feed_child(command)
 
     def configure(self, widget, data = None):
       ui = {}
