@@ -401,7 +401,7 @@ class Terminator(Borg):
             window.grab_focus()
             try:
                 t = GdkX11.x11_get_server_time(window.get_window())
-            except AttributeError:
+            except (TypeError, AttributeError):
                 t = 0
             window.get_window().focus(t)
 
@@ -417,7 +417,7 @@ class Terminator(Borg):
                 window.grab_focus()
                 try:
                     t = GdkX11.x11_get_server_time(window.get_window())
-                except AttributeError:
+                except (TypeError, AttributeError):
                     t = 0
                 window.get_window().focus(t)
 
