@@ -311,7 +311,7 @@ class Window(Container, Gtk.Window):
             self.grab_focus()
             try:
                 t = GdkX11.x11_get_server_time(self.get_window())
-            except AttributeError:
+            except (TypeError, AttributeError):
                 t = 0
             self.get_window().focus(t)
         else:
